Name:           python-mdp
Version:        3.5
Release:        7%{?dist}
Summary:        Library for building data processing pipelines for machine learning

License:        BSD
URL:            http://mdp-toolkit.sourceforge.net/
Source0:        https://github.com/mdp-toolkit/mdp-toolkit/archive/MDP-%{version}.tar.gz
Source1:        https://github.com/mdp-toolkit/mdp-docs/archive/MDP-%{version}.tar.gz#/MDP-docs-%{version}.tar.gz
# also:         https://pypi.python.org/pypi/MDP
Patch1:         0001-FIX-added-missing-file-closing-in-hinet-slideshow-co.patch
Patch2:         0002-Revert-FIX-fix-bug-with-pytest-when-MDP-is-installed.patch
Patch3:         0003-Fix-test-failure.patch

BuildArch:      noarch
BuildRequires:  python2-devel
BuildRequires:  python2-future
BuildRequires:  numpy
BuildRequires:  scipy
# python-shogun version that is in Fedora is unsupported
BuildRequires:  libsvm-python
BuildRequires:  python-joblib
BuildRequires:  python-scikit-learn
BuildRequires:  pytest

BuildRequires:  python3-devel
BuildRequires:  python3-future
BuildRequires:  python3-numpy
BuildRequires:  python3-scipy
# libsvm-python3 is missing
BuildRequires:  python3-joblib
BuildRequires:  python3-scikit-learn
BuildRequires:  python3-pytest

# documentation
BuildRequires:  make
BuildRequires:  python3-sphinx
BuildRequires:  epydoc
BuildRequires:  graphviz

%global _description \
The Modular toolkit for Data Processing (MDP) package is a library of  \
widely used data processing algorithms, and the possibility to combine \
them together to form pipelines for building more complex data         \
processing software. MDP has been designed to be used as-is and as a   \
framework for scientific data processing development.                  \
                                                                       \
From the user’s perspective, MDP consists of a collection of units,    \
which process data. For example, these include algorithms for          \
supervised and unsupervised learning, principal and independent        \
components analysis and classification. These units can be chained     \
into data processing flows, to create pipelines as well as more        \
complex feed-forward network architectures. Given a set of input data, \
MDP takes care of training and executing all nodes in the network in   \
the correct order and passing intermediate data between the            \
nodes. This allows the user to specify complex algorithms as a series  \
of simpler data processing steps.

%description %_description

%package     -n python2-mdp
Summary:     %{summary}
Requires:    python2-future
Requires:    numpy
Requires:    scipy
Recommends:  libsvm-python
Recommends:  python2-joblib
Recommends:  python-scikit-learn
Recommends:  python-pytest
Provides:    python2-bimdp = %{version}-%{release}
%{?python_provide:%python_provide python2-mdp}
%{?python_provide:%python_provide python2-bimdp}

%description -n python2-mdp %_description

%package     -n python3-mdp
Summary:     %{summary}
Requires:    python3-future
Requires:    python3-numpy
Requires:    python3-scipy
Recommends:  python3-joblib
Recommends:  python3-scikit-learn
Recommends:  python3-pytest
Provides:    python3-bimdp = %{version}-%{release}
%{?python_provide:%python_provide python3-mdp}
%{?python_provide:%python_provide python3-bimdp}

%description -n python3-mdp %_description

%package     doc
Summary:     API documentation and tutorials for MDP
%description doc
%{summary}.

Also available online at http://mdp-toolkit.sourceforge.net.

%prep
%autosetup -n mdp-toolkit-MDP-%{version} -a1 -p1

%build
%py2_build
%py3_build
pushd mdp-docs-MDP-%{version}
ln -s .. mdp-toolkit
PYTHONPATH=.. make \
              MDPTOOLKIT=.. \
              SPHINXBUILD=sphinx-build-%{python3_version} \
              LINKS=local \
              epydoc codesnippet html
rm build/html/.buildinfo

%install
%py2_install
%py3_install

%check
%{__python2} setup.py test
%{__python3} setup.py test

%global _docdir_fmt %{name}

%files -n python2-mdp
%{python2_sitelib}/*
%license COPYRIGHT
# README and CHANGES are not useful

%files -n python3-mdp
%{python3_sitelib}/*
%license COPYRIGHT

%files doc
%doc mdp-docs-MDP-%{version}/build/html

%changelog
* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.5-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jan 10 2017 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 3.5-6
- Backport upstream patches to fix build

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 3.5-5
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.5-4
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Mar 10 2016 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 3.5-3
- Run tests with fixed seed

* Wed Mar  9 2016 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 3.5-2
- Disable failing test

* Tue Mar  8 2016 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 3.5-1
- Initial packaging
